@@ -4,9 +4,9 @@ from notecoin.database.connect import RedisConnect
 from notecoin.strategy.utils import account_api
 
 
-class AccountCoins(RedisConnect):
+class AccountAccount(RedisConnect):
     def __init__(self, prefix="/account", cache_prefix='okex_account_balance', *args, **kwargs):
-        super(AccountCoins, self).__init__(prefix=prefix, cache_prefix=cache_prefix, *args, **kwargs)
+        super(AccountAccount, self).__init__(prefix=prefix, cache_prefix=cache_prefix, *args, **kwargs)
         add_api_routes(self)
 
     @api_route('/update', description="update market tickers")
@@ -17,4 +17,4 @@ class AccountCoins(RedisConnect):
 
     @api_route('/read', description="read market tickers")
     def get_value(self, suffix=""):
-        return super(AccountCoins, self).get_value(suffix=suffix)
+        return super(AccountAccount, self).get_value(suffix=suffix)
